<?php

namespace Teknisa\SM\Factory;
use Doctrine\ORM\EntityManager;

class Sm00013000GeracaoPropostaFactory {
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    public function excluirEscopos(array $params) {
        $sql = "DELETE FROM FCT_ESCOPOGERACAOPROP
                 WHERE NRGERACAOPROPOSTA = :NRGERACAOPROPOSTA
                   AND NRORG             = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function excluirItensEscoposNaoSelecionados(array $params, $strEscopos) {
        $sql = "DELETE FROM FCT_ITESCOPOGERACAOPROP
                 WHERE NRGERACAOPROPOSTA = :NRGERACAOPROPOSTA
                   AND NRORG             = :NRORG
                   AND NRTIPOORCAMENTO NOT IN ($strEscopos)";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function inserirEscopos(array $params) {
        $sql = "INSERT INTO FCT_ESCOPOGERACAOPROP (
                    NRGERACAOPROPOSTA,  NRTIPOORCAMENTO,    NRORG,
                    IDATIVO,            NRORGINCLUSAO,      DTINCLUSAO,
                    CDOPERINCLUSAO
                )
                VALUES (
                    :NRGERACAOPROPOSTA,  :NRTIPOORCAMENTO,    :NRORG,
                    :IDATIVO,            :NRORGINCLUSAO,      SYSDATE,
                    :CDOPERINCLUSAO
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function inserirComposicao(array $params) {
        $sql = "INSERT INTO FCT_COMPSERVGERACAOPROP (
                    NRCOMPSERVGERACAOPROP,  NRGERACAOPROPOSTA,  NRCOMPSERVICO,
                    NRCOMPSERVICOPAI,       IDCOMPOBRIGATORIA,  IDESCOLHIDO,
                    NRORG,                  IDATIVO,            NRORGINCLUSAO,
                    DTINCLUSAO,             CDOPERINCLUSAO
                )
                VALUES (
                    :NRCOMPSERVGERACAOPROP,  :NRGERACAOPROPOSTA,  :NRCOMPSERVICO,
                    :NRCOMPSERVICOPAI,       :IDCOMPOBRIGATORIA,  :IDESCOLHIDO,
                    :NRORG,                  :IDATIVO,            :NRORGINCLUSAO,
                    SYSDATE,                 :CDOPERINCLUSAO
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function inserirElemento(array $params) {
        $sql = "INSERT INTO FCT_ELEMENTOGERACAOPROP (
                    NRELEMENTOGERACAOPROP,  NRGERACAOPROPOSTA,  NRCOMPSERVICO,
                    NRITCOMPSERVICO,        IDELEMENTO,         IDELEMENTOPAI,
                    IDTIPOELEMENTO,         IDSERVOBRIGCOMP,    IDESCOLHIDO,
                    NRORG,                  IDATIVO,            NRORGINCLUSAO,
                    DTINCLUSAO,             CDOPERINCLUSAO
                )
                VALUES (
                    :NRELEMENTOGERACAOPROP,  :NRGERACAOPROPOSTA,  :NRCOMPSERVICO,
                    :NRITCOMPSERVICO,        :IDELEMENTO,         :IDELEMENTOPAI,
                    :IDTIPOELEMENTO,         :IDSERVOBRIGCOMP,    :IDESCOLHIDO,
                    :NRORG,                  :IDATIVO,            :NRORGINCLUSAO,
                    SYSDATE,                 :CDOPERINCLUSAO
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function inserirMedidas(array $params) {
        $sql = "INSERT INTO FCT_MEDVARGERACAOPROP (
                    NRGERACAOPROPOSTA,  IDELEMENTORAIZ,  CDTPMEDIDAVARIAVEL,
                    QTMINIMA,           QTMAXIMA,        QTFRANQUIA,
                    NRORG,              IDATIVO,         NRORGINCLUSAO,
                    DTINCLUSAO,         CDOPERINCLUSAO
                )
                VALUES (
                    :NRGERACAOPROPOSTA,  :IDELEMENTORAIZ,  :CDTPMEDIDAVARIAVEL,
                    :QTMINIMA,           :QTMAXIMA,        :QTFRANQUIA,
                    :NRORG,              :IDATIVO,         :NRORGINCLUSAO,
                    SYSDATE,             :CDOPERINCLUSAO
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function excluirComposicoes(array $params) {
        $sql = "DELETE FROM FCT_COMPSERVGERACAOPROP
                 WHERE NRGERACAOPROPOSTA = :NRGERACAOPROPOSTA
                   AND NRORG             = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function excluirElementos(array $params) {
        $sql = "DELETE FROM FCT_ELEMENTOGERACAOPROP
                 WHERE NRGERACAOPROPOSTA = :NRGERACAOPROPOSTA
                   AND NRORG             = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function excluirMedidas(array $params) {
        $sql = "DELETE FROM FCT_MEDVARGERACAOPROP
                 WHERE NRGERACAOPROPOSTA = :NRGERACAOPROPOSTA
                   AND NRORG             = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getMedidasVariaveis(array $params) {
        $sql = "SELECT MEDVAR.IDELEMENTORAIZ,
                       ELEMENTO.NMSERVORCA AS NMELEMENTORAIZ,
                       MEDVAR.CDTPMEDIDAVARIAVEL,
                       MEDIDA.DSTPMEDIDASERV AS DSTPMEDIDAVARIAVEL,
                       MEDVAR.QTMINIMA,
                       MEDVAR.QTMAXIMA,
                       MEDVAR.QTFRANQUIA
                  FROM FCT_MEDVARGERACAOPROP MEDVAR
                  LEFT JOIN FCT_SERVICOORCA ELEMENTO
                    ON MEDVAR.IDELEMENTORAIZ = ELEMENTO.IDELEMENTO
                  LEFT JOIN FCT_TIPOMEDIDASERV MEDIDA
                    ON MEDVAR.CDTPMEDIDAVARIAVEL = MEDIDA.CDTPMEDIDASERV
                 WHERE MEDVAR.NRGERACAOPROPOSTA = :NRGERACAOPROPOSTA
                   AND MEDVAR.NRORG             = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getEscopos(array $params) {
        $sql = "SELECT ESCGP.NRTIPOORCAMENTO,
                       ESCOPO.NMTIPOORCAMENTO
                  FROM FCT_ESCOPOGERACAOPROP ESCGP
                 INNER JOIN FCT_TIPOORCAMENTO ESCOPO
                    ON ESCGP.NRTIPOORCAMENTO = ESCOPO.NRTIPOORCAMENTO
                 WHERE ESCGP.NRGERACAOPROPOSTA = :NRGERACAOPROPOSTA
                   AND ESCGP.NRORG             = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
}