<?php
namespace Teknisa\SM\Service;
use Doctrine\ORM\EntityManager;
use Teknisa\SM\Service\Sm00001000LancamentoPropostaService;
use Teknisa\SM\Service\Sm00004000ContratoService;

class ger00045000ProspectService{
    protected $newCode;
    protected $prospectFactory;
    protected $propostaService;
    protected $contratoService;
    protected $entityManager;
    
    public function __construct ($prospectFactory, $newCode, Sm00001000LancamentoPropostaService $propostaService, Sm00004000ContratoService $contratoService, EntityManager $entityManager){
        $this->connection       = $entityManager->getConnection();
        $this->prospectFactory  = $prospectFactory;
        $this->newCode          = $newCode;
        $this->propostaService  = $propostaService;
        $this->contratoService  = $contratoService;
        $this->entityManager    = $entityManager;
    }
    
    /**
     * Busca o número do parceiro de negócio do operador 
     * logado
    **/
    public function getNrParcNegocio($cdoperador, $nrorg){
        $params = array(
            "CDOPERADOR" => $cdoperador,
            "NRORG"      => $nrorg
        );
        
        $result = $this->prospectFactory->getNrParcNegocio($params);
        return (count($result) > 0) ? $result[0]["NRPARCNEGOCIO"] : null;
    }
    
    public function prepareInsertProspectEvolutionNextTask($row){

        $row["NRSEQFILACONTA"] = $this->newCode->getCodeByTableName("FILACONTATO", $row["NRORG"]);

        $paramsInsertProspectEvolNextTask = array(
            "DSFILACONTATO"         => $row["DSFILACONTATO"],
            "DTPLANFILACONTA"       => $row["DTPLANFILACONTA"],
            "CDOPERREAL"            => $row["CDOPERREAL"],
            "NRSEQFILACONTA"        => $row["NRSEQFILACONTA"],
            "NRORG"                 => $row["NRORG"],
            "NRORGINCLUSAO"         => $row["NRORG"],
            "CDOPERINCLUSAO"        => $row["CDOPEREVOL"],
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "NRCONTATO"             => $row["NRSEQCONTATO"],
            "NRSEQCONTATO"          => $row["NRSEQCONTATO"],
            "NRSEQINTERLOCUTOR"         => empty($row['NRSEQINTERLOCUTOR']) ? '' : $row['NRSEQINTERLOCUTOR'],
            "DSEMAILTAREFA"             => empty($row['EMAILINTERLOC']) ? '' : $row['EMAILINTERLOC'],
            "DSTELEFONETAREFA"          => empty($row['NRTELEFONE1']) ? '' : $row['NRTELEFONE1'],
        );
        
        $this->prospectFactory->insertProspectEvolNextTask($paramsInsertProspectEvolNextTask);
        return $row["NRSEQFILACONTA"];
        
    }
    
    public function verificaTarefas($row){
        
        $paramsVerificaTarefas = array(
            
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "NRORG"                 => $row["NRORG"]
            
        );
        
        $retorno = $this->prospectFactory->verificaTarefas($paramsVerificaTarefas);
        if(count($retorno) > 0){
            return $retorno;
        }
        
        return false;
    }
    
    public function getOperador($cdoperador, $nrorg){
        
        $paramsSelectOperador = array(
            "CDOPERREAL"            => $cdoperador,
            "NRORG"                 => $nrorg
        );
        
        $retorno = $this->prospectFactory->getOperador($paramsSelectOperador);
        
        if(!empty($retorno)){
            return $retorno[0]['NMOPERADOR'];
        }else{
            return false;
        }
        
        
    }
    
     public function getParceiro($parcnegocio, $nrorg){
        
        $paramsSelectParceiro = array(
            "NRPARCNEGOCIO"           => $parcnegocio,
            "NRORG"                 => $nrorg
        );
        
        $retorno = $this->prospectFactory->getParceiro($paramsSelectParceiro);
        
        if(!empty($retorno)){
            return $retorno[0]['NMPRINCIPALPARC'];
        }else{
            return false;
        }
    }
    
    public function prepareSelectProspectContact($row){
        $paramsSelectProspectContact = array(
            
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "NRORG"                 => $row["NRORG"]
            
        );
        
        $retorno = $this->prospectFactory->selectProspectContact($paramsSelectProspectContact);
        if(count($retorno) > 0){
            return $retorno[0];
        }
        
        return array();
    }
    
    public function callForInsertNrseqcontatoForNewOpportunity($row){
        
        $paramsUpdateOpportunity = array(
        
            "NRSEQOPORT"            => $row["NRSEQOPORT"],
            "NRSEQCONTATO"          => $row["NRSEQCONTATO"]
        
        );
        
        $this->prospectFactory->requestForInsertNrseqcontatoForNewOpportunity($paramsUpdateOpportunity);
        
    }
    
    public function callForUpdatePartnerType($row){
        
        $paramsUpdatePartnerType = array(
        
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"]
            
        );
        
        $this->prospectFactory->requestForUpdatePartnerType($paramsUpdatePartnerType);
        
    }
    
    public function callForInsertPartnershipOfTypeClient($row){
        
        $row["NRPARCERIA"] = $this->newCode->getCodeByTableName("PARCERIA", $row["NRORG"]);
        
        $paramsInsertPartnership = array(
            
            "NRPARCERIA"            => $row["NRPARCERIA"],
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "NRORG"                 => $row["NRORG"],
            "NRORGINCLUSAO"         => $row["NRORG"],
            "CDOPERINCLUSAO"        => $row["CDOPERADOR"]
            
        );
        
        $this->prospectFactory->requestForInsertPartnershipOfTypeClient($paramsInsertPartnership);
        
    }
    
    public function callForInsertClient($row){
        
        if(!isset($row["NRFUNCPROS"])){
            
            $row["NRFUNCPROS"] = $row["NMRAZSOCPROS"];
            
        }
        
        $paramsInsertClient = array(
            
            "CDCLIENTE"             => $row["CDCLIENTE"],
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "IDTPIJURCLIE"          => $row["IDTPIJURPROS"],
            "NRINSJURCLIE"          => $row["NRINSJURPROS"],
            "NMRAZSOCCLIE"          => $row["NMRAZSOCPROS"],
            "NMFANTCLIE"            => $row["NRFUNCPROS"],
            "NRORG"                 => $row["NRORG"],
            "NRORGINCLUSAO"         => $row["NRORGINCLUSAO"],
            "CDOPERINCLUSAO"        => $row["CDOPERINCLUSAO"]
            
        );
        
        $this->prospectFactory->requestForInsertClient($paramsInsertClient);
        
    }
    
    public function callForDeactivateProspect($row){
        
        $paramsUpdateProspect = array(
            
            "CDPROSPECT"            => $row["CDPROSPECT"]
        
        );
        
        $this->prospectFactory->requestForDeactivateProspect($paramsUpdateProspect);
    }
    
    public function callForInsertClientAddress($row){
        
        $paramsInsertClientAddress = array(
            
            "CDCLIENTE"             => $row["CDCLIENTE"],
            "CDPAIS"                => $row["CDPAIS"],
            "SGESTADO"              => $row["SGESTADO"],
            "CDMUNICIPIO"           => $row["CDMUNICIPIO"],
            "CDBAIRRO"              => $row["CDBAIRRO"],
            "DSENDECLIE"            => $row["DSENDECLIE"],
            "IDTPENDECLIE"          => $row["IDTPENDECLIE"],
            "NMBAIRCLIE"            => $row["NMBAIRCLIE"],
            "DSCOMPENDCLI"          => $row["DSCOMPENDCLI"],
            "NRCEPCLIE"             => $row["NRCEPCLIE"],
            "NRTELECLIE"            => $row["NRTELECLIE"],
            "NRRAMALCLIE"           => $row["NRRAMALCLIE"],
            "DSEMAILCLIE"           => $row["DSEMAILCLIE"],
            "NRORG"                 => $row["NRORG"],
            "NRORGINCLUSAO"         => $row["NRORG"],
            "CDOPERINCLUSAO"        => $row["CDOPERADOR"],
            "NRENDERECOPARC"        => $row["NRENDERECOPARC"]
        );
        
        $this->prospectFactory->requestForInsertClientAddress($paramsInsertClientAddress);
        
    }
    
    public function callForSelectAddressProspect($row){
        
        $paramsSelectProspectAddress = array(
            "CDPROSPECT"            => $row["CDPROSPECT"],
            "NRORG"                 => $row["NRORG"]
        );
        
        $returnedAddress = $this->prospectFactory->requestForSelectProspectAddress($paramsSelectProspectAddress);
        return $returnedAddress;
    }
    
    public function callForSetTaskEndDate($row){
        
        $paramsSetTaskEndDate = array(
            
            "NRSEQFILACONTA"        => $row["NRSEQFILACONTA"]
            
        );
        
        $this->prospectFactory->requestForSetTaskEndDate($paramsSetTaskEndDate);
        
    }
    
    public function callForDeactivateProspectTask($taskUpdateParams){
        
        $this->prospectFactory->requestForDeactivateProspectTask($taskUpdateParams);
        
    }
    
    public function replicaInterlocutorProspect($row){
        $dataParams = array(
            "NRRELACIONAPARC"   => $row['NRRELACIONAPARC'],
            "NRORG"             => $row['NRORG']
        );
        
        $nrparcnegocioInterlocutor = $this->prospectFactory->getInterlocutorParc($dataParams);
        if($row['REPLICAENDERECO'] == true){
            $nrenderecoparcInterlocutor = $this->prospectFactory->getEnderecoparcInterlocutor($nrparcnegocioInterlocutor, $row['NRORG']);
            if($nrenderecoparcInterlocutor){
                $paramsUpdate = array(
                    "CDTIPOENDERECO" => $row['IDENDEINPROS'] == 'R' ? 'OUTROS' : 'COMERCIAL' ,
                    "NRORGULTATU" => $row['NRORG'],
                    "CDOPERULTATU" => $row['CODOPERLOGGED'],
                    "CDPAIS" => $row['CDPAIS'],
                    "SGESTADO" => $row['SGESTADO'],
                    "CDMUNICIPIO" => isset($row['CDMUNICIPIO']) ? $row['CDMUNICIPIO'] : '',
                    "CDBAIRRO" => isset($row['CDBAIRRO']) ? $row['CDBAIRRO'] : '',
                    "NMBAIRROENDERECO" => $row['NMBAIRINPROS'],
                    "DSENDERECO" => $row['DSENDEINPROS'],
                    "NRCEPENDERECO" => $row['NRCEPINPROS'],
                    "NRPARCNEGOCIO" => $nrparcnegocioInterlocutor,
                    "NRORG" => $row['NRORG'],
                    "NRENDERECOPARC" => $nrenderecoparcInterlocutor
                );
                $this->prospectFactory->replicaEnderecoparcInterlocutor($paramsUpdate);
            }else{
                $paramsInsert = array(
                    "IDATIVO" => $row['IDATIVO'],
                    "NRPARCNEGOCIO" => $nrparcnegocioInterlocutor,
                    "NRORG" => $row['NRORG'],
                    "NRENDERECOPARC" => $this->newCode->getCodeByTableName("ENDERECOPARC", $row["NRORG"]),
                    "CDTIPOENDERECO" => $row['IDENDEINPROS'] == 'R' ? 'OUTROS' : 'COMERCIAL',
                    "NRORGINCLUSAO" => $row['NRORG'],
                    "CDOPERINCLUSAO" => $row['CODOPERLOGGED'],
                    "CDPAIS" => $row['CDPAIS'],
                    "SGESTADO" => $row['SGESTADO'],
                    "CDMUNICIPIO" => isset($row['CDMUNICIPIO']) ? $row['CDMUNICIPIO'] : '',
                    "CDBAIRRO" => isset($row['CDBAIRRO']) ? $row['CDBAIRRO'] : '',
                    "NMBAIRROENDERECO" => $row['NMBAIRINPROS'],
                    "DSENDERECO" => $row['DSENDEINPROS'],
                    "NRCEPENDERECO" => $row['NRCEPINPROS'],
                    "DSCOMPLEENDERECO" => '',
                    "NRIMOVELENDERECO" => ''
                );
                $this->prospectFactory->insertEnderecoparc($paramsInsert);
            }
        }
    }
    
    public function setIdQualificadoProspect($row){
        
        $paramsSetQualification = array(
            
            "IDQUALIFICADO"         => $row['IDQUALIFICADO'],
            "CDPROSPECT"            => $row["CDPROSPECT"],
            "NRORG"                 => $row["NRORG"]
        );
        
        $this->prospectFactory->setIdQualificadoProspect($paramsSetQualification);
        
    }
    
    public function insertConcorrProspect($row){
        
        $paramsInsertConcorrParc = array(
            
            "NRCONCORRPROSPECT"     => $row["NRCONCORRPROSPECT"],
            "CDPROSPECT"            => $row["CDPROSPECT"],
            "NRCONCORRENTE"         => $row["NRCONCORRENTE"],
            "NRORG"                 => $row["NRORG"],
            "DTINIVIGENCIA"         => $row["DTINIVIGENCIA"],
            "DTFIMVIGENCIA"         => $row["DTFIMVIGENCIA"],
            "CDOPERINCLUSAO"        => $row["CODOPERLOGGED"]
            
        );
        
        $this->prospectFactory->insertConcorrProspect($paramsInsertConcorrParc);
        
    }  
    
    public function updateConcorrProspect($row){
        
        $paramsUpdateConcorrParc = array(
            
            "NRCONCORRPROSPECT"     => $row["NRCONCORRPROSPECT"],
            "NRORG"                 => $row["NRORG"],
            "NRCONCORRENTE"         => $row["NRCONCORRENTE"],
            "DTINIVIGENCIA"         => $row["DTINIVIGENCIA"],
            "DTFIMVIGENCIA"         => $row["DTFIMVIGENCIA"]
            
        );
        
        $this->prospectFactory->updateConcorrProspect($paramsUpdateConcorrParc);
        
    }
    
     public function deleteConcorrProspect($row){
        
        $paramsDeleteConcorrParc = array(
            
            "NRCONCORRPROSPECT"     => $row["NRCONCORRPROSPECT"],
            "NRORG"                 => $row["NRORG"]
            
        );
        
        $this->prospectFactory->deleteConcorrProspect($paramsDeleteConcorrParc);
        
    }
    
    public function validaCNPJCliente($row){
        
        $paramsSelectClient = array(
            
            "CNPJ"                  => $row["CNPJ"],
            "NRORG"                 => $row["NRORG"]
            
        );
        
        $returnedClients = $this->prospectFactory->validaCNPJCliente($paramsSelectClient);
        if(isset($returnedClients[0])){
            return $returnedClients;
        }else{
            return true;
        }
    }
    
    public function createPartnership($row) {
        $nrParcnegocio = $row['NRPARCNEGOCIO'];
        $nrparceiro = $row['NRPARCERIA'];
        $nrOrg = $row['NRORG'];
        $cdoperinclusao = $row['CDOPERINCLUSAO'];
        $cdtipoparceiro = $row["CDTIPOPARCEIRO"]; 
        $params = array(
          "NRPARCERIA"     => $nrparceiro,
          "NRORG"          => $nrOrg,
          "NRPARCNEGOCIO"  => $nrParcnegocio,
          "CDTIPOPARCEIRO" => $cdtipoparceiro,
          "IDATIVO"        => 'S',
          "CDOPERINCLUSAO" => $cdoperinclusao,
          "NRORGINCLUSAO"  => $nrOrg);
        
        $this->prospectFactory->createPartnership($params);
    }
    
    public function setParceiroNegocio($row)
    {

        $params = array
        (
            "IDATIVO"               => $row["IDATIVO"],
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "NRORG"                 => $row["NRORG"],
            "NMPRINCIPALPARC"       => $row["NMRAZSOCPROS"],
            "NMSECUNDARIPARC"       => empty($row["NMFANTPROS"]) ? $row["NMRAZSOCPROS"] : $row["NMFANTPROS"] ,
            "NRINSCRICAOPARC"       => $row["NRINSJURPROS"],
            "NRORGINCLUSAO"         => $row["NRORG"],
            "CDOPERINCLUSAO"        => $row["CDOPERINCLUSAO"],
            "CDTIPOPARCPRINCIPAL"   => "PROSPECT",
            "CDTIPOINSCRICAO"       => $row["TIPOINSC"],
            "IDPESSOAFISICA"        => $row["ISCPF"],
        );

        $this->prospectFactory->setParceiroNegocio($params);
    }

    public function newContato($row) {

        if(empty($row['CDFILIAL'])) $row['CDFILIAL'] = '9999';
        $params = array(

            "DSREFECONT"    => substr('Referente ao Lead '.$row['NMRAZSOCPROS'], 0, 59),
            "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO'],
            "NRSEQCONTATO"  => $row['NRSEQCONTATO'],
            "CDOPERCONT"    => $row['CDOPERINCLUSAO'],
            "NRCONTATO"     => $row['NRCONTATO'],
            "CDFILIAL"      => $row['CDFILIAL'],
            "NRORG"         => $row['NRORG'],
            "IDSTATUSCONT"  =>'A',
            "IDTPCONTATO"   =>'P'

        );
        
        $this->prospectFactory->newContato($params);
    }
    
    public function validaLead($row){
        if(!empty($row['INSCRICAO'])){
            $paramsVerifyLeadCPNJ = array(
                "INSCRICAO"            => $row["INSCRICAO"],
                "NRORG"                => $row["NRORG"]
            );
            if($row['IDTPIJURCAN'] == 'J'){
                $leads = $this->prospectFactory->verifyLeadCNPJ($paramsVerifyLeadCPNJ, $row['TABELA'], $row['FIELDINSC'], $row['FIELDNOME']);
            } else {
                $leads = $this->prospectFactory->verifyLeadInsc($paramsVerifyLeadCPNJ, $row['TABELA'], $row['FIELDINSC'], $row['FIELDNOME']);
            }
        } else {
            $leads = array();
        }
        if(empty($leads)){
            $paramsVerifyLeadName = array(
                "NOME"  => $row["NOME"],
                "NRORG" => $row["NRORG"]
            );
            $leads = $this->prospectFactory->verifyLeadName($paramsVerifyLeadName, $row['TABELA'], $row['FIELDNOME']); 
            if(!empty($leads)){
                $leads = true;
            } else {
                $leads = false;
            }
            
        }
        return $leads;
    }
    
    public function insereEnderecoProspect($insere, $nrenderecoparc, $nrparcnegocio, $cdtipoendereco, $nrorg, $idativo, $dtinclusao, $nrorginclusao, $cdoperinclusao, $cdpais, $sgestado, $cdmunicipio, $cdbairro, $nmbairroendereco, $dscompleendereco, $nrcependereco, $dsendereco, $nrimovelendereco, $dsreferenciaende, $operador){
        
        if ($insere == true){
            
            $paramsinsereEnderecoProspect = array(
                "NRENDERECOPARC"   => $nrenderecoparc,
                "NRPARCNEGOCIO"    => $nrparcnegocio,
                "CDTIPOENDERECO"   => $cdtipoendereco,
                "NRORG"            => $nrorg,
                "IDATIVO"          => $idativo,
                "DTINCLUSAO"       => $dtinclusao,
                "NRORGINCLUSAO"    => $nrorginclusao,
                "CDOPERINCLUSAO"   => $cdoperinclusao,
                "CDPAIS"           => $cdpais,
                "SGESTADO"         => $sgestado,
                "CDMUNICIPIO"      => $cdmunicipio,
                "CDBAIRRO"         => $cdbairro,
                "NMBAIRROENDERECO" => $nmbairroendereco,
                "DSCOMPLEENDERECO" => $dscompleendereco,
                "NRCEPENDERECO"    => $nrcependereco,
                "DSENDERECO"       => $dsendereco,
                "NRIMOVELENDERECO" => $nrimovelendereco,
                "DSREFERENCIAENDE" => $dsreferenciaende
             );
             
            $this->prospectFactory->insereEnderecoProspect($paramsinsereEnderecoProspect);
        }
        else{
            
            $paramsinsereEnderecoProspect = array(
                "CDTIPOENDERECO"   => $cdtipoendereco,
                "CDPAIS"           => $cdpais,
                "SGESTADO"         => $sgestado,
                "CDMUNICIPIO"      => $cdmunicipio,
                "CDBAIRRO"         => $cdbairro,
                "NMBAIRROENDERECO" => $nmbairroendereco,
                "DSCOMPLEENDERECO" => $dscompleendereco,
                "NRCEPENDERECO"    => $nrcependereco,
                "DSENDERECO"       => $dsendereco,
                "NRIMOVELENDERECO" => $nrimovelendereco,
                "DSREFERENCIAENDE" => $dsreferenciaende,
                "OPERADOR"         => $operador,
                "NRENDERECOPARC"   => $nrenderecoparc,
                "NRPARCNEGOCIO"    => $nrparcnegocio,
                "NRORG"            => $nrorg
            );
            
            $this->prospectFactory->editaEnderecoProspect($paramsinsereEnderecoProspect);
        }
    }
    
    public function insereInterlocutorProspect($insere, $nrseqinterlocutor,$nminterlocutor, $nrparcnegocio, $emailinterloc, $nrtelefone1, $nrtelefone2, $nrtelefone3, $nrtelefone4, $cdcargointerloc, $dtnascimento, $idrecebepresente, $cdpais, $sgestado, $cdmunicipio, $cdbairro, $nrcepinterlocutor, $dsendeinterlocutor, $dscompinterlocutor, $nrendeinterlocutor, $nrorg, $idativo, $dtinclusao, $cdoperinclusao, $cdsetor, $nrcpfinterloc, $operador){
        
        if ($insere == true){
            
            $paramsinsereInterlocProspect = array(
                "NRSEQINTERLOCUTOR"  =>  $nrseqinterlocutor,
                "NMINTERLOCUTOR"     =>  $nminterlocutor,
                "NRPARCNEGOCIO"      =>  $nrparcnegocio,
                "EMAILINTERLOC"      =>  $emailinterloc,              
                "NRTELEFONE1"        =>  $nrtelefone1,              
                "NRTELEFONE2"        =>  $nrtelefone2,              
                "NRTELEFONE3"        =>  $nrtelefone3,              
                "NRTELEFONE4"        =>  $nrtelefone4,              
                "CDCARGOINTERLOC"    =>  $cdcargointerloc,               
                "DTNASCIMENTO"       =>  $dtnascimento,                      
                "IDRECEBEPRESENTE"   =>  $idrecebepresente,              
                "CDPAIS"             =>  $cdpais,              
                "SGESTADO"           =>  $sgestado,              
                "CDMUNICIPIO"        =>  $cdmunicipio,              
                "CDBAIRRO"           =>  $cdbairro,              
                "NRCEPINTERLOCUTOR"  =>  $nrcepinterlocutor,              
                "DSENDEINTERLOCUTOR" =>  $dsendeinterlocutor,              
                "DSCOMPINTERLOCUTOR" =>  $dscompinterlocutor,              
                "NRENDEINTERLOCUTOR" =>  $nrendeinterlocutor,                    
                "NRORG"              =>  $nrorg, 
                "IDATIVO"            =>  $idativo,     
                "DTINCLUSAO"         =>  $dtinclusao,           
                "NRORGINCLUSAO"      =>  $nrorg,
                "CDOPERINCLUSAO"     =>  $cdoperinclusao,
                "CDSETOR"            =>  $cdsetor,               
                "NRCPFINTERLOC"      =>  $nrcpfinterloc
             );
             
            $this->prospectFactory->insereInterlocutorProspect($paramsinsereInterlocProspect);
        }
        else{
            
            $paramsinsereInterlocProspect = array(
                "NMINTERLOCUTOR"     =>  $nminterlocutor,
                "EMAILINTERLOC"      =>  $emailinterloc,              
                "NRTELEFONE1"        =>  $nrtelefone1,              
                "NRTELEFONE2"        =>  $nrtelefone2,              
                "NRTELEFONE3"        =>  $nrtelefone3,              
                "NRTELEFONE4"        =>  $nrtelefone4,              
                "CDCARGOINTERLOC"    =>  $cdcargointerloc,               
                "DTNASCIMENTO"       =>  $dtnascimento,                      
                "IDRECEBEPRESENTE"   =>  $idrecebepresente,              
                "CDPAIS"             =>  $cdpais,              
                "SGESTADO"           =>  $sgestado,              
                "CDMUNICIPIO"        =>  $cdmunicipio,              
                "CDBAIRRO"           =>  $cdbairro,              
                "NRCEPINTERLOCUTOR"  =>  $nrcepinterlocutor,              
                "DSENDEINTERLOCUTOR" =>  $dsendeinterlocutor,              
                "DSCOMPINTERLOCUTOR" =>  $dscompinterlocutor,              
                "NRENDEINTERLOCUTOR" =>  $nrendeinterlocutor,                    
                "CDSETOR"            =>  $cdsetor,               
                "NRCPFINTERLOC"      =>  $nrcpfinterloc,
                "OPERADOR"           =>  $operador,
                "NRSEQINTERLOCUTOR"  =>  $nrseqinterlocutor,
                "NRPARCNEGOCIO"      =>  $nrparcnegocio,
                "NRORG"              =>  $nrorg
            );
            
            $this->prospectFactory->editaInterlocutorProspect($paramsinsereInterlocProspect);
        }
    }
    
    public function inserecrmInterlocutor($nrseqinterlocutor, $nrparcnegocio, $nomeInterlocutor, $emailinterloc, $telInterloc, $nrorg, $operador){
        
        $paramsinsereInterlocProspect = array(
            "NRSEQINTERLOCUTOR"  =>  $nrseqinterlocutor,
            "NMINTERLOCUTOR"     =>  $nomeInterlocutor,
            "NRPARCNEGOCIO"      =>  $nrparcnegocio,
            "EMAILINTERLOC"      =>  $emailinterloc,              
            "NRTELEFONE1"        =>  $telInterloc,              
            "NRORG"              =>  $nrorg, 
            "IDATIVO"            =>  'S',     
            "NRORGINCLUSAO"      =>  $nrorg,
            "CDOPERINCLUSAO"     =>  $operador
         );
         
        $this->prospectFactory->inserecrmInterlocutor($paramsinsereInterlocProspect);
        
    }
    
     public function insereInteProsp($cdintepros, $cdprospect, $nomeInterlocutor, $emailinterloc, $telInterloc, $nrorg, $operador){
        
        $paramsinsereInterlocProspect = array(
            "CDINTEPROS"  =>  $cdintepros,
            "CDPROSPECT"      =>  $cdprospect,
            "NMINTEPROS"     =>  $nomeInterlocutor,
            "DSEMAILIPROS"      =>  $emailinterloc,              
            "NRTEL1INPROS"        =>  $telInterloc,              
            "NRORG"              =>  $nrorg, 
            "IDATIVO"            =>  'S',     
            "NRORGINCLUSAO"      =>  $nrorg,
            "CDOPERINCLUSAO"     =>  $operador,
            "IDTPINTEPROS" =>  'F'
         );
         
        $this->prospectFactory->insereInteProsp($paramsinsereInterlocProspect);
        
    }
    
    public function insereEnderecoParc($nrenderecoparc, $nrparcnegocio, $cep, $endereço, $numero, $complemento, $pais, $estado, $municipio, $bairro, $nmbairro, $nrorg, $operador){
            
        $params = array(
            "NRENDERECOPARC"   => $nrenderecoparc,
            "NRPARCNEGOCIO"    => $nrparcnegocio,
            "CDTIPOENDERECO"   => 'PRINCIPAL',
            "NRORG"            => $nrorg,
            "IDATIVO"          => 'S',
            "NRORGINCLUSAO"    => $nrorg,
            "CDOPERINCLUSAO"   => $operador,
            "NRCEPENDERECO"    => $cep,
            "DSENDERECO"       => $endereço,
            "NRIMOVELENDERECO" => $numero,
            "DSCOMPLEENDERECO" => $complemento,
            "CDPAIS"           => $pais,
            "SGESTADO"         => $estado,
            "CDMUNICIPIO"      => $municipio,
            "CDBAIRRO"         => $bairro,
            "NMBAIRROENDERECO" => $nmbairro
         );
         
        $this->prospectFactory->insereEnderecoParc($params);
    }
    
    /**
     * Prepara para editar os operadores responsáveis dos prospects selecionados
    **/
    public function salvarAlteracoesOpersResp($prospect, $operador, $nrorg, $alteraProp, $alteraCont){
        try{
            $this->connection->beginTransaction();
            $prospect = implode("','", $prospect);
            $oldprospect = $this->prospectFactory->getCdOperadorResponsavel($nrorg, $prospect);
            $params = array(
                "NRPARCRESPROSP" => $operador,
                "NRORG"          => $nrorg
            );
            
            $this->prospectFactory->salvarAlteracoesOpersResp($prospect, $params);
            $this->prospectFactory->salvarAlteracoesOpersRespParc($prospect, $params);
            $nrparceiro = $oldoperador = array();
            foreach ($oldprospect as $prosp) {
                array_push($nrparceiro , $prosp["NRPARCNEGOCIO"]);
            }
            
            $nrparceiro = implode(",", $nrparceiro);
            $sql = "NRPARCNEGOCIO IN($nrparceiro)";
            if($alteraProp == "Y")
                $this->propostaService->atualizaOperadorResponsavel($sql, $this->prospectFactory->getCdNewOperadorResponsavel($params), $nrorg);
            if($alteraCont == "Y")
                $this->contratoService->atualizaOperadorResponsavel($sql, $this->prospectFactory->getCdNewOperadorResponsavel($params), $nrorg);
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    
     /**
     * A função "buscaFilialHierarquia" busca a filial vinculado ao operador 
     * na hierarquiia de operadores (CRM_HIERARQUIAOPER)
     */
     
    public function buscaFilialHierarquia($operador, $nrorg){
        
        try{ 
            $params = array(
                "CDOPERADOR"  => $operador,
                "NRORG"       => $nrorg
            );
                
            $result = $this->prospectFactory->buscaFilialHierarquia($params);
            return isset($result) ? $result : null;
        } catch(\Exception $e){
            throw $e;
        }
    }
    
}
?>
